assert(RCD_Display, "RaidCooldowns_Display not found!")
local MINOR_VERSION = tonumber(("$Revision: 71293 $"):match("%d+"))
if MINOR_VERSION > RCD_Display.MINOR_VERSION then RCD_Display.MINOR_VERSION = MINOR_VERSION end

local L = LibStub("AceLocale-3.0"):GetLocale("RaidCooldowns_Display")
local Media = LibStub("LibSharedMedia-3.0")
local textures = Media:List("statusbar")
local fonts = Media:List("font")
--local backgrounds = Media:List("background")
--local borders = Media:List("border")

local pairs, ipairs = _G.pairs, _G.ipairs
local tonumber, tostring = _G.tonumber, _G.tostring

Media.RegisterCallback(RCD_Display, "LibSharedMedia_Registered", "UpdateDisplay")
Media.RegisterCallback(RCD_Display, "LibSharedMedia_SetGlobal", "UpdateDisplay")

-- Omen rip; most of this file is, actually
local function GetLSMIndex(t, value)
	for k, v in pairs(Media:List(t)) do
		if v == value then
			return k
		end
	end
	return nil
end

local options = {
	type = "group",
	args = {
		test = {
			type = "execute",
			name = L["Test"],
			desc = L["Test"],
			func = RCD_Display.Test,
		},
		display = {
			type = "group",
			name = L["Display Options"],
			desc = L["Display Options"],
			cmdHidden = true,
			args = {
				lock = {
					type = "toggle",
					name = L["Lock Anchor"],
					desc = L["Locks the anchor in place and prevents it from being dragged."],
					get = function(info) return RCD_Display.db.profile.locked end,
					set = function(info, v)
						RCD_Display.db.profile.locked = v
						RCD_Display:UpdateDisplay()
					end
				},
				scale = {
					type = "range",
					name = L["Scale"],
					desc = L["Control the scale of the entire RaidCooldowns GUI"],
					min = 1,
					max = 150,
					step = 1,
					bigStep = 1,
					get = function(info) return RCD_Display.db.profile.scale end,
					set = function(info, v)
						RCD_Display.db.profile.scale = v
						RCD_Display:UpdateDisplay()
					end					
				},
				growUp = {
					type = "toggle",
					name = L["Grow Up"],
					desc = L["Grow bars upwards"],
					get = function(info) return RCD_Display.db.profile.growUp end,
					set = function(info, v)
						RCD_Display.db.profile.growUp = v
						RCD_Display:UpdateDisplay()
					end
				},
				bars = {
					type = "group",
					name = L["Bar options"],
					desc = L["Options which affect the style of the cooldown bars"],
					args = {
						texture = {
							type = "select",
							name = L["Texture"],
							desc = L["The texture that the bar will use"],
							values = textures,
							get = function(info) return GetLSMIndex("statusbar", RCD_Display.db.profile.texture) end,
							set = function(info, v)
								RCD_Display.db.profile.texture = Media:List("statusbar")[v]
								RCD_Display:UpdateDisplay()
							end
						},
						fontFace = {
							type = "select",
							name = L["Label Font"],
							desc = L["The font that the bar labels will use"],
							values = fonts,
							get = function(info) return GetLSMIndex("font", RCD_Display.db.profile.fontFace) end,
							set = function(info, v)
								RCD_Display.db.profile.fontFace = Media:List("font")[v]
								RCD_Display:UpdateDisplay()
							end							
						},
						fontSize = {
							type = "range",
							name = L["Label Font Size"],
							desc = L["The size of the font that the bar labels will use"],
							min = 5,
							max = 30,
							step = 1,
							bigStep = 1,
							get = function(info) return RCD_Display.db.profile.fontSize end,
							set = function(info, v)
								RCD_Display.db.profile.fontSize = v
								RCD_Display:UpdateDisplay()
							end
						},
						--[[
						height = {
							type = "range",
							name = L["Height"],
							desc = L["Height of each bar"],
							min = 5,
							max = 50,
							step = 1,
							bigStep = 1,
							get = function(info) return RCD_Display.db.profile.height end,
							set = function(info, v)
								RCD_Display.db.profile.height = v
								--RCD_Display:UpdateDisplay()
							end
						},
						]]
					}
				},
			},
		},
		spells = {
			type = "group",
			name = L["Spell Options"],
			desc = L["Configure which spell cooldowns are shown and which aren't"],
			cmdHidden = true,
			args = {
				hideSelf = {
					type = "toggle",
					name = L["Hide Self"],
					desc = L["Hide your own cooldowns."],
					order = 1,
					get = function(info) return RCD_Display.db.profile.hideSelf end,
					set = function(info, v)
						RCD_Display.db.profile.hideSelf = v
					end
				},
				message = {
					type = "toggle",
					name = L["Ready Message"],
					desc = L["Print a chat message after a cooldown is ready."],
					order = 2,
					get = function(info) return RCD_Display.db.profile.readyMsg end,
					set = function(info, v)
						RCD_Display.db.profile.readyMsg = v
					end
				},
			},
		},
		config = {
			type = "execute",
			name = L["Configure"],
			desc = L["Open the configuration dialog"],
			func = RCD_Display.ShowConfig,
			guiHidden = true
		}
	}
}

do
	local classes = {"DRUID", "HUNTER", "MAGE", "PALADIN", "PRIEST", "ROGUE", "SHAMAN", "WARLOCK", "WARRIOR"}
	local t = options.args.spells.args
	local i = 5 -- Sorting
	
	for _, v in ipairs(classes) do
		-- Separate class spells with a header
		t[v] = {
			type = "header",
			name = L[v],
			cmdHidden = true,
			order = i,
		}
		i = i + 1
		
		-- Add an option entry for each spell
		for k2, v2 in pairs(RCD_Display.cooldowns[v]) do
			t[tostring(v2)] = {
				type = "toggle",
				name = k2,
				desc = L["Display %s cooldowns"]:format(k2),
				order = i,
				get = function(info) return RCD_Display.db.profile.spells[v2] end,
				set = function(info, val)
					RCD_Display.db.profile.spells[v2] = val
					RCD_Display:SpellToggle(v2, val)
				end,
				cmdHidden = true,
			}
			i = i + 1
		end
	end
end

RCD_Display.configOptions = options
LibStub("AceConfig-3.0"):RegisterOptionsTable(L["RaidCooldowns"], options, "rcd")